import { AbstractDynamicSnippetsGeneratorContext, FernGeneratorExec } from '@fern-api/browser-compatible-base-generator';
import { FernIr } from '@fern-api/dynamic-ir-sdk';
import { go, BaseGoCustomConfigSchema } from '@fern-api/go-ast';

declare namespace DynamicTypeInstantiationMapper {
    interface Args {
        typeReference: FernIr.dynamic.TypeReference;
        value: unknown;
        as?: ConvertedAs;
    }
    type ConvertedAs = "key";
}
declare class DynamicTypeInstantiationMapper {
    private context;
    constructor({ context }: {
        context: DynamicSnippetsGeneratorContext;
    });
    convert(args: DynamicTypeInstantiationMapper.Args): go.TypeInstantiation;
    private convertList;
    private convertMap;
    private convertNamed;
    private convertDiscriminatedUnion;
    private getBaseFields;
    private convertObject;
    private convertEnum;
    private getEnumValueName;
    private convertUndicriminatedUnion;
    private findMatchingUndiscriminatedUnionType;
    private getUndiscriminatedUnionFieldName;
    private getUndiscriminatedUnionFieldNameForList;
    private getUndiscriminatedUnionFieldNameForMap;
    private getUndiscriminatedUnionFieldNameForOptional;
    private getUndiscriminatedUnionFieldNameForSet;
    private getUndiscriminatedUnionFieldNameForLiteral;
    private getUndiscriminatedUnionFieldNameForPrimitive;
    private convertUnknown;
    private convertPrimitive;
    private getValueAsNumber;
    private getValueAsBoolean;
}

declare namespace DynamicTypeMapper {
    interface Args {
        typeReference: FernIr.dynamic.TypeReference;
    }
}
declare class DynamicTypeMapper {
    private context;
    constructor({ context }: {
        context: DynamicSnippetsGeneratorContext;
    });
    convert(args: DynamicTypeMapper.Args): go.Type;
    private convertLiteral;
    private convertNamed;
    private convertUnknown;
    private convertPrimitive;
}

interface FilePropertyInfo {
    fileFields: go.StructField[];
    bodyPropertyFields: go.StructField[];
}
declare class FilePropertyMapper {
    private context;
    constructor({ context }: {
        context: DynamicSnippetsGeneratorContext;
    });
    getFilePropertyInfo({ body, value }: {
        body: FernIr.dynamic.FileUploadRequestBody;
        value: unknown;
    }): FilePropertyInfo;
    private getSingleFileProperty;
    private getArrayFileProperty;
    private getBodyProperty;
}

declare class DynamicSnippetsGeneratorContext extends AbstractDynamicSnippetsGeneratorContext {
    ir: FernIr.dynamic.DynamicIntermediateRepresentation;
    customConfig: BaseGoCustomConfigSchema | undefined;
    dynamicTypeMapper: DynamicTypeMapper;
    dynamicTypeInstantiationMapper: DynamicTypeInstantiationMapper;
    filePropertyMapper: FilePropertyMapper;
    rootImportPath: string;
    constructor({ ir, config }: {
        ir: FernIr.dynamic.DynamicIntermediateRepresentation;
        config: FernGeneratorExec.GeneratorConfig;
    });
    clone(): DynamicSnippetsGeneratorContext;
    getMethodName(name: FernIr.Name): string;
    getTypeName(name: FernIr.Name): string;
    getImportPath(fernFilepath: FernIr.FernFilepath): string;
    getContextTypeReference(): go.TypeReference;
    getContextTodoFunctionInvocation(): go.FuncInvocation;
    getIoReaderTypeReference(): go.TypeReference;
    getNewStringsReaderFunctionInvocation(s: string): go.FuncInvocation;
    getClientConstructorName(): string;
    getClientImportPath(): string;
    getOptionImportPath(): string;
    getGoTypeReferenceFromDeclaration({ declaration }: {
        declaration: FernIr.dynamic.Declaration;
    }): go.TypeReference;
    getEnvironmentTypeReferenceFromID(environmentID: string): go.TypeReference | undefined;
    private getEnvironmentTypeReference;
}

export { DynamicSnippetsGeneratorContext as D, type FilePropertyInfo as F, DynamicTypeInstantiationMapper as a, DynamicTypeMapper as b, FilePropertyMapper as c };
